==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: de\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "Anruf"

, "Calls"
: "Anrufe"

, "Line"
: "Leitung"

, "Caller Id"
: "Eigene Rufnummer"

, "Start"
: "Start"

, "Connected"
: "Verbunden"

, "Disconnected"
: "Getrennt"

, "Duration"
: "Dauer"

, "Ringing"
: "Klingeln"

, "Direction"
: "Richtung"

, "Source"
: "Quelle"

, "Destination"
: "Gesprächspartner"

, "Phone"
: "Telefon"

, "Phones"
: "Telefone"

, "Settings"
: "Einstellungen"

, "Lines"
: "Leitungen"

, "Description"
: "Beschreibung"

, "Number"
: "Nummer"

, "Cancel"
: "Abbrechen"

, "Dial"
: "Wählen"

, "Error"
: "Fehler"

, "Not possible to dial."
: "Wählen nicht möglich."

, "Edit phone settings"
: "Telefoneinstellungen bearbeiten"

, "Dial number"
: "Nummer wählen"

, "Initiate a new outgoing call"
: "Neuer ausgehender Anruf"

, "No phone selected"
: "Kein Telefon ausgewählt"

, "Please select the desired phone in the tree!"
: "Bitte wählen Sie ein Telefon im Baum aus!"

, "Call contact"
: "Kontakt anrufen"

, "Work"
: "Geschäftlich"

, "Home"
: "Privat"

, "Cell"
: "Handy"

, "Cell private"
: "Handy privat"

, "Incoming call"
: "Eingehender Anruf"

, "Outgoing call"
: "Ausgehender Anruf"

, "unknown number"
: "Unbekannte Rufnummer"

, "local prefix for outgoing calls"
: "lokaler Präfix für ausgehende Anrufe"

, "telephone area code"
: "Telefon Vorwahl"

, "regex for local calls"
: "regex für Ortsgespräche"

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: "eigene Telefonnummer"

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "Anrufe in dieser Woche"

, "Incoming and outgoing calls of this week"
: "Eingehende und ausgehende Anrufe dieser Woche"

, "Calls last week"
: "Anrufe in der letzten Woche"

, "Incoming and outgoing calls of last week"
: "Eingehende und ausgehende Anrufe letzter Woche"

, "Calls this month"
: "Anrufe in diesem Monat"

, "Incoming and outgoing calls of this month"
: "Eingehende und ausgehende Anrufe dieses Monats"

, "Calls last month"
: "Anrufe im letzten Monat"

, "Incoming and outgoing calls of last month"
: "Eingehende und ausgehende Anrufe letzten Monats"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-04-07 13:29+0200\nLast-Translator: Paul Hartog <p.hartog@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.3\n"

, "Incoming call"
: "Eingehender Anruf"

, "Outgoing call"
: "Ausgehender Anruf"

, "unknown number"
: "Unbekannte Rufnummer"

, "Phone"
: "Telefon"

, "Line"
: "Leitung"

, "Number"
: "Nummer"

, "Cancel"
: "Abbrechen"

, "Dial"
: "Wählen"

, "Error"
: "Fehler"

, "Not possible to dial."
: "Wählen nicht möglich."

, "Call contact"
: "Kontakt anrufen"

, "Work"
: "Geschäftlich"

, "Home"
: "Privat"

, "Cell"
: "Handy"

, "Cell private"
: "Handy privat"

, "Edit phone settings"
: "Telefoneinstellungen bearbeiten"

, "Dial number"
: "Nummer wählen"

, "Initiate a new outgoing call"
: "Neuer ausgehender Anruf"

, "Phones"
: "Telefone"

, "No phone selected"
: "Kein Telefon ausgewählt"

, "Please select the desired phone in the tree!"
: "Bitte wählen Sie das gewünschte Telefon aus der Struktur!"

, "Calls this week"
: "Anrufe in dieser Woche"

, "Calls last week"
: "Anrufe in der letzten Woche"

, "Calls this month"
: "Anrufe in diesem Monat"

, "Calls last month"
: "Anrufe im letzten Monat"

, "Incoming and outgoing calls of this week"
: "Eingehende und ausgehende Anrufe dieser Woche"

, "Incoming and outgoing calls of last week"
: "Eingehende und ausgehende Anrufe letzter Woche"

, "Incoming and outgoing calls of this month"
: "Eingehende und ausgehende Anrufe dieses Monats"

, "Incoming and outgoing calls of last month"
: "Eingehende und ausgehende Anrufe letzten Monats"

, "Local prefix for outgoing calls"
: "Lokaler Präfix für ausgehende Anrufe"

, "telephone area code"
: "Telefon Vorwahl"

, "regex for local calls"
: "regex für Ortsgespräche"

, "Identifies if a calling number is a local call without leading area code."
: "Gibt an, ob es sich bei einer Rufnummer um einen Ortsgespräch ohne führende Vorwahl handelt."

, "own telephone number"
: "eigene Telefonnummer"

, "Own telephone number to prefix to internal calls."
: "Eigene Telefonnummer als Präfix für interne Anrufe."

, "Call"
: "Anruf"

, "Calls"
: "Anrufe"

, "Caller Id"
: "Eigene Rufnummer"

, "Start"
: "Start"

, "Connected"
: "Verbunden"

, "Disconnected"
: "Getrennt"

, "Duration"
: "Dauer"

, "Ringing"
: "Klingeln"

, "Direction"
: "Richtung"

, "Source"
: "Quelle"

, "Destination"
: "Gesprächspartner"

, "resolved destination"
: ""

, "Settings"
: "Einstellungen"

, "Lines"
: "Leitungen"

, "Description"
: "Beschreibung"




}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
